==> haskell-data-default-0.7.1.2-14-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-data-default.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 data-default
version:              0.7.1.2
visibility:           public
id:                   data-default-0.7.1.2-CrFQ4dgXZ2xCKxCENN7hDD
key:                  data-default-0.7.1.2-CrFQ4dgXZ2xCKxCENN7hDD
license:              BSD-3-Clause
copyright:            (c) 2013 Lukas Mai
maintainer:           <lukasmai.403+hackage@gmail.com>
author:               Lukas Mai
synopsis:             A class for types with a default value
category:             Data
abi:                  91885abaa28a12c4db9ddb3e652b2143
exposed:              True
exposed-modules:      Data.Default
import-dirs:          /usr/lib/ghc-9.4.8/site-local/data-default-0.7.1.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/data-default-0.7.1.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/data-default-0.7.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-data-default
hs-libraries:         HSdata-default-0.7.1.2-CrFQ4dgXZ2xCKxCENN7hDD
depends:
    base-4.17.2.1 data-default-class-0.1.2.1-J2UCuIureY5CbnU1SgrtGb
    data-default-instances-containers-0.1.0.3-9AZa3k8GyIQ5Jra3Lt11HS
    data-default-instances-dlist-0.0.1.2-DQTXU9LByEnGZ9HYv9g238
    data-default-instances-old-locale-0.0.1.1-9qJoP0h8lKv246PgEbx1ol

haddock-interfaces:
    /usr/share/doc/haskell-data-default/html/data-default.haddock

haddock-html:         /usr/share/doc/haskell-data-default/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-data-default-0.7.1.2-23-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-data-default.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 data-default
version:              0.7.1.2
visibility:           public
id:                   data-default-0.7.1.2-8yRIq8kwMNHG7OFJsT5Ayy
key:                  data-default-0.7.1.2-8yRIq8kwMNHG7OFJsT5Ayy
license:              BSD-3-Clause
copyright:            (c) 2013 Lukas Mai
maintainer:           <lukasmai.403+hackage@gmail.com>
author:               Lukas Mai
synopsis:             A class for types with a default value
category:             Data
abi:                  88f7746ad217b53d1cea6bd88f2de82a
exposed:              True
exposed-modules:      Data.Default
import-dirs:          /usr/lib/ghc-9.4.8/site-local/data-default-0.7.1.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/data-default-0.7.1.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/data-default-0.7.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-data-default
hs-libraries:         HSdata-default-0.7.1.2-8yRIq8kwMNHG7OFJsT5Ayy
depends:
    base-4.17.2.1 data-default-class-0.1.2.1-J2UCuIureY5CbnU1SgrtGb
    data-default-instances-containers-0.1.0.3-9AZa3k8GyIQ5Jra3Lt11HS
    data-default-instances-dlist-0.0.1.2-DGM4Amkjoyw9A6KD5II8wa
    data-default-instances-old-locale-0.0.1.1-9qJoP0h8lKv246PgEbx1ol

haddock-interfaces:
    /usr/share/doc/haskell-data-default/html/data-default.haddock

haddock-html:         /usr/share/doc/haskell-data-default/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
